summaryrefslogtreecommitdiff
path: root/framework/Web/UI/TControl.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Web/UI/TControl.php')
-rw-r--r--framework/Web/UI/TControl.php10
1 files changed, 8 insertions, 2 deletions
diff --git a/framework/Web/UI/TControl.php b/framework/Web/UI/TControl.php
index f12504be..eb5c016e 100644
--- a/framework/Web/UI/TControl.php
+++ b/framework/Web/UI/TControl.php
@@ -2142,7 +2142,8 @@ interface IButtonControl
* ISurroundable interface
*
* Identifies controls that may create an additional surrounding tag. The id of the
* tag can be obtained with {@link getSurroundingTagID}.
*
* @package System.Web.UI
* @since 3.1.2
@@ -2150,7 +2151,12 @@ interface IButtonControl
interface ISurroundable
{
/**
- * @return string the id of the embedding tag of the control or the control's clientID if not surrounded
+ * @return string the tag used to wrap the control in (if surrounding is needed).
+ */
+ public function getSurroundingTag();
+
+ /**
+ * @return string the id of the embedding tag of the control or the control's clientID if not surrounded.
*/
public function getSurroundingTagID();
}
@@ -2142,7 +2142,8 @@ interface IButtonControl
*
* Identifies controls that may create an additional surrounding tag. The id of the
- * tag can be obtained with {@link getSurroundingTagID}.
+ * tag can be obtained with {@link getSurroundingTagID}, the tag used to render the
+ * surrounding container is obtained by {@link getSurroundingTag}.
*
* @package System.Web.UI